<br />
<p align="center">
  <h3 align="center">SEALy</h3>

  <p align="center">
    <a href="https://www.microsoft.com/en-us/research/project/microsoft-seal"><strong>Microsoft SEAL bindings for Rust and Python</strong></a>
    <br />
  </p>
</p>

### 🌟 SEALy

Microsoft SEAL bindings for Rust and Python.
